\name{GLDEX-package}
\alias{GLDEX-package}
\alias{GLDEX}
\docType{package}
\title{
This package fits RS and FMKL generalised lambda distributions using discretised and maximum likelihood methods. 
It also provides functions for fitting bimodal distributions using mixtures of generalised lambda distributions.
}
\description{
The fitting algorithms considered in this package have two major objectives. One is to provide a smoothing device
to fit distributions to data using the weight and unweighted discretised approach based on the bin width of the 
histogram. The other is to provide a definitive fit to the data set using the maximum likelihood estimation.
}
\details{
\tabular{ll}{
Package: \tab GLDEX\cr
Type: \tab Package\cr
Version: \tab 1.0\cr
Date: \tab 2006-03-23\cr
License: \tab GPL (Version 2 or later)\cr
}
This package allows a direct fitting method onto the data set using \code{\link{fun.RMFMKL.ml}}, \code{\link{fun.RMFMKL.hs}}, \code{\link{fun.RMFMKL.hs.nw}},
\code{\link{fun.RPRS.ml}}, \code{\link{fun.RPRS.hs}}, \code{\link{fun.RPRS.hs.nw}} and in the case of bimodal data set: \code{\link{fun.auto.bimodal.ml}}, \code{\link{fun.auto.bimodal.pml}} functions.
The resulting fits can be graphically gauged by \code{\link{fun.plot.fit}} or \code{\link{fun.plot.fit.bm}} (for bimodal data), or examined by numbers
using the Kolmogorov-Smirnoff resample tests (\code{fun.diag.ks.g} and \code{\link{fun.diag.ks.g.bimodal}}). For unimodal data fits, it is also
possible to compare the mean, variance, skewness and kurtosis of the fitted distribution with the data set using
\code{\link{fun.comp.moments.ml}} and \code{\link{fun.comp.moments.ml.2}} functions. Similarly, for bimodal data fits,
this is done via \code{\link{fun.theo.bi.mv.gld}} and \code{\link{fun.moments}}. Additionally, quantile plots can be used
to examine the goodness of fit, these are in \code{\link{qqplot.gld}} and \code{\link{qqplot.gld.bi}} for univariate and
bimodal generalised lambda distribution fits respectively.
}
\author{
Steve Su <allegro1978@hotmail.com>
}
\references{
Freimer, M., Mudholkar, G. S., Kollia, G. & Lin, C. T. (1988), A study of the generalized tukey lambda family, Communications in Statistics - Theory and Methods *17*, 3547-3567. 

Gilchrist, Warren G. (2000), Statistical Modelling with Quantile Functions, Chapman & Hall 

Karian, Z.A., Dudewicz, E.J., and McDonald, P. (1996), The extended generalized lambda distribution system for fitting distributions to data: history, completion of theory, tables, applications, the ``Final Word'' on Moment fits, Communications in Statistics - Simulation and Computation *25*, 611-642. 

Karian, Zaven A. and Dudewicz, Edward J. (2000), Fitting statistical distributions: the Generalized Lambda Distribution and Generalized Bootstrap methods, Chapman & Hall 

King, R.A.R. & MacGillivray, H. L. (1999), A starship method for fitting the generalised lambda distributions, Australian and New Zealand Journal of Statistics, 41, 353-374 

Ramberg, J. S. & Schmeiser, B. W. (1974), An approximate method for generating asymmetric random variables, Communications of the ACM *17*, 78-82. 

Su, S. (2005). "A Discretized Approach to Flexibly Fit Generalized Lambda Distributions to Data." Journal of Modern Applied Statistical Methods(November): 408-424.

Su (2007). Nmerical Maximum Log Likelihood Estimation for Generalized Lambda Distributions.  Computational Statistics and Data Analysis: *51*, 8, 3983-3998.

Su (2006) Maximum Log Likelihood Estimation using EM Algorithm and Partition Maximum Log Likelihood Estimation for Mixtures of Generalized Lambda Distributions. Working Paper. 
}
\seealso{
\pkg{gld} package in R.
}
\examples{

#### Univariate distributions example:

set.seed(1000)

junk<-rweibull(300,3,2)

### Using discretised approach, with 50 classes

# Using discretised method with weights
obj.fit1.hs<-fun.data.fit.hs(junk)

# Plot the resulting fit. The fun.plot.fit function also works for singular fits 
# such as those by fun.plot.fit(obj.fit1.ml,junk,nclass=50,
# param=c("rs","fmkl","fmkl"),xlab="x")
fun.plot.fit(obj.fit1.hs,junk,nclass=50,param=c("rs","fmkl"),xlab="x")

# Compare the mean, variance, skewness and kurtosis of the fitted distribution 
# with actual data
fun.theo.mv.gld(obj.fit1.hs[1,1],obj.fit1.hs[2,1],obj.fit1.hs[3,1],
obj.fit1.hs[4,1],param="rs")
fun.theo.mv.gld(obj.fit1.hs[1,2],obj.fit1.hs[2,2],obj.fit1.hs[3,2],
obj.fit1.hs[4,2],param="fmkl")
fun.moments(junk)

# Conduct resample KS tests
fun.diag.ks.g(obj.fit1.hs[,1],junk,param="rs")
fun.diag.ks.g(obj.fit1.hs[,2],junk,param="fmkl")

### Try another fit, say 15 classes

obj.fit2.hs<-fun.data.fit.hs(junk,rs.default="N",fmkl.default="N",no.c.rs = 15, 
no.c.fmkl = 15)

fun.plot.fit(obj.fit2.hs,junk,nclass=50,param=c("rs","fmkl"),xlab="x")

fun.theo.mv.gld(obj.fit2.hs[1,1],obj.fit2.hs[2,1],obj.fit2.hs[3,1],
obj.fit2.hs[4,1],param="rs")
fun.theo.mv.gld(obj.fit2.hs[1,2],obj.fit2.hs[2,2],obj.fit2.hs[3,2],
obj.fit2.hs[4,2],param="fmkl")
fun.moments(junk)

fun.diag.ks.g(obj.fit2.hs[,1],junk,param="rs")
fun.diag.ks.g(obj.fit2.hs[,2],junk,param="fmkl")

### Uses the maximum likelihood estimation method

# Fit the function using fun.data.fit.ml
obj.fit1.ml<-fun.data.fit.ml(junk)

# Plot the resulting fit
fun.plot.fit(obj.fit1.ml,junk,nclass=50,param=c("rs","fmkl","fmkl"),xlab="x",
name=".ML")

# Compare the mean, variance, skewness and kurtosis of the fitted distribution 
# with actual data
fun.comp.moments.ml(obj.fit1.ml,junk)

# Do a quantile plot

qqplot.gld(junk,obj.fit1.ml[,1],param="rs",name="RS ML fit")

# Run a KS resample test on the resulting fit
fun.diag2(obj.fit1.ml,junk,1000)

# It is possible to use say fun.data.fit.ml(junk,rs.leap=409,fmkl.leap=409,
# FUN="QUnif") to find solution under a different set of low discrepancy number 
# generators.

#### Bimodal distributions example:

par(mfrow=c(2,1))

# Fitting mixture of generalised lambda distributions on the data set using both 
# the maximum likelihood and partition maximum likelihood and plot the resulting 
# fits

junk<-fun.auto.bimodal.ml(faithful[,1],per.of.mix=0.01,clustering.m=clara,
init1.sel="rprs",init2.sel="rmfmkl",init1=c(-1.5,1.5),init2=c(-0.25,1.5),
leap1=3,leap2=3)
fun.plot.fit.bm(nclass=50,fit.obj=junk,data=faithful[,1],
name="Maximum likelihood using",xlab="faithful1",param.vec=c("rs","fmkl"))

# Do a quantile plot

qqplot.gld.bi(faithful[,1],junk$par,param1="rs",param2="fmkl",
name="RS FMKL ML fit",range=c(0.001,0.999))

junk<-fun.auto.bimodal.pml(faithful[,1],clustering.m=clara,init1.sel="rprs",
init2.sel="rmfmkl",init1=c(-1.5,1.5),init2=c(-0.25,1.5),leap1=3,leap2=3)
fun.plot.fit.bm(nclass=50,fit.obj=junk,data=faithful[,1],
name="Partition maximum likelihood using",xlab="faithful1",
param.vec=c("rs","fmkl"))

# Fit the faithful[,1] data from the dataset library using sobol sequence 
# generator for the first distribution fit and halton sequence for the second 
# distribution fit.
fit1<-fun.auto.bimodal.ml(faithful[,1],init1.sel="rmfmkl",init2.sel="rmfmkl",
init1=c(-0.25,1.5),init2=c(-0.25,1.5),leap1=3,leap2=3,fun1="runif.sobol",
fun2="runif.halton")

# Run diagnostic KS tests
fun.diag.ks.g.bimodal(fit1$par[1:4],fit1$par[5:8],prop1=fit1$par[9],
data=faithful[,1],param1="fmkl",param2="fmkl")

# Find the theoretical moments of the fit
fun.theo.bi.mv.gld(fit1$par[1],fit1$par[2],fit1$par[3],fit1$par[4],"fmkl",
fit1$par[5],fit1$par[6],fit1$par[7],fit1$par[8],"fmkl",fit1$par[9])

# Compare this with the empirical moments from the data set.
fun.moments(faithful[,1])

# Do a quantile plot
qqplot.gld.bi(faithful[,1],fit1$par,param1="fmkl",param2="fmkl",
name="FMKL FMKL ML fit")

# Generate random observations from FMKL generalised lambda distributions with 
# parameters (1,2,3,4) and (4,3,2,1) with 50\% of data from each distribution.
fun.simu.bimodal(c(1,2,3,4),c(4,3,2,1),prop1=0.5,param1="fmkl",param2="fmkl")
}
\keyword{distribution} 
\keyword{smooth}