\name{cut.default}
\alias{cut.default}

\title{ A slightly modified cut function for this package }
\description{
  \code{cut} divides the range of 'x' into intervals and codes the values in 'x' according to which interval they fall. The leftmost
  interval corresponds to level one, the next leftmost to level two and so on. This function performs similar tasks to 
  the default function "cut" in R.The only difference is in one of the checking conditions. See Details.
}
\usage{
cut.default(x, breaks, labels = NULL, include.lowest = FALSE, right = TRUE, dig.lab = 3, \dots)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{x}{ A numeric vector which is to be converted to a factor by
          cutting. }
  \item{breaks}{ Either a vector of cut points or number giving the number of
          intervals which 'x' is to be cut into. }
  \item{labels}{ Labels for the levels of the resulting category.  By default,
          labels are constructed using '"(a,b]"' interval notation. If
          'labels = FALSE', simple integer codes are returned instead
          of a factor. }
  \item{include.lowest}{ Logical, indicating if an 'x[i]' equal to the lowest
          (or highest, for 'right = FALSE') 'breaks' value should be
          included. }
  \item{right}{ Logical, indicating if the intervals should be closed on the
          right (and open on the left) or vice versa. }
  \item{dig.lab}{ Integer which is used when labels are not given. It
          determines the number of digits used in formatting the break
          numbers. }
  \item{\dots}{ Further arguments passed to or from other methods. }
}
\details{
  This function uses: \code{if (is.na(breaks) | breaks < 1) stop("invalid number of intervals")} in one of 
  its checking conditions rather than the default:
  \code{if (is.na(breaks) | breaks < 2) stop("invalid number of intervals")}. This will allow
  cut to work when the \code{breaks = 1}.
}
\value{
   A 'factor' is returned, unless 'labels = FALSE' which results in
     the mere integer level codes.
}
\references{ Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988) The New S
     Language. Wadsworth & Brooks/Cole.
 }
\author{ R }
\note{ Instead of \code{table(cut(x, br))}, \code{hist(x, br, plot = FALSE)} is
     more efficient and less memory hungry.  Instead of \code{cut(*, labels
     = FALSE)}, \code{findInterval()} is more efficient.
}
\seealso{ \code{\link{split}} for splitting a variable according to a group factor;
     \code{\link{factor}}, \code{\link{tabulate}}, \code{\link{table}}, \code{\link{findInterval}} }
\examples{
     Z <- rnorm(10000)
     table(cut(Z, br = -6:6))
     sum(table(cut(Z, br = -6:6, labels=FALSE)))
     sum(   hist  (Z, br = -6:6, plot=FALSE)$counts)

     cut(rep(1,5),4)#-- dummy
     tx0 <- c(9, 4, 6, 5, 3, 10, 5, 3, 5)
     x <- rep(0:8, tx0)
     stopifnot(table(x) == tx0)

     table( cut(x, b = 8))
     table( cut(x, br = 3*(-2:5)))
     table( cut(x, br = 3*(-2:5), right = FALSE))

     ##--- some values OUTSIDE the breaks :
     table(cx  <- cut(x, br = 2*(0:4)))
     table(cxl <- cut(x, br = 2*(0:4), right = FALSE))
     which(is.na(cx));  x[is.na(cx)]  #-- the first 9  values  0
     which(is.na(cxl)); x[is.na(cxl)] #-- the last  5  values  8

     ## Label construction:
     y <- rnorm(100)
     table(cut(y, breaks = pi/3*(-3:3)))
     table(cut(y, breaks = pi/3*(-3:3), dig.lab=4))

     table(cut(y, breaks =  1*(-3:3), dig.lab=4))
     # extra digits don't "harm" here
     table(cut(y, breaks =  1*(-3:3), right = FALSE))
     #- the same, since no exact INT!

     ## sometimes the default dig.lab is not enough to be avoid confusion:
     aaa <- c(1,2,3,4,5,2,3,4,5,6,7)
     cut(aaa, 3)
     cut(aaa, 3, dig.lab=4)
}
\keyword{manip}
